package org.rcisoft.business.cmsActivity.controller;


/*固定导入*/

import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.rcisoft.business.cmsActivity.entity.CmsActivity;
import org.rcisoft.business.cmsActivity.service.CmsActivityService;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.rcisoft.core.util.CyResultGenUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.util.List;

/**
 * @author cy
 * @date 2024年3月25日 下午1:42:40
 */
@RestController
@RequestMapping("/cmsActivity")
public class CmsActivityController extends CyPaginationController<CmsActivity> {


    @Autowired
    private CmsActivityService cmsActivityServiceImpl;

    @PreAuthorize("@cyPerm.hasPerm('cms:activity:increase')")
    @CyOpeLogAnno(title = "system-活动管理-新增活动", businessType = CyLogTypeEnum.INSERT)
    @ApiOperation(value = "添加活动", notes = "添加活动")
    @PostMapping(value = "/add")
    public CyResult add(@Valid CmsActivity cmsActivity, BindingResult bindingResult) {
        CyPersistModel data = cmsActivityServiceImpl.persist(cmsActivity);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                cmsActivity);
    }

    @PreAuthorize("@cyPerm.hasPerm('cms:activity:removing')")
    @CyOpeLogAnno(title = "system-活动管理-删除活动", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value = "删除活动", notes = "删除活动")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/delete/{businessId:\\w+}")
    public CyResult delete(@PathVariable Integer businessId, CmsActivity cmsActivity) {
        cmsActivity.setBusinessId(businessId);
        CyPersistModel data = cmsActivityServiceImpl.remove(cmsActivity);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                businessId);
    }

    @PreAuthorize("@cyPerm.hasPerm('cms:activity:modifications')")
    @CyOpeLogAnno(title = "system-活动管理-修改活动", businessType = CyLogTypeEnum.INSERT)
    @ApiOperation(value = "修改活动", notes = "修改活动")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PostMapping("/update/{businessId:\\w+}")
    public CyResult update(@PathVariable Integer businessId, @Valid CmsActivity cmsActivity, BindingResult bindingResult) {
        cmsActivity.setBusinessId(businessId);
        CyPersistModel data = cmsActivityServiceImpl.merge(cmsActivity);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                cmsActivity);
    }

//    @PreAuthorize("@cyPerm.hasPerm('cms:activity:singleSearch')")
    @CyOpeLogAnno(title = "system-活动管理-查询活动", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "查询单一活动", notes = "查询单一活动")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @GetMapping("/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable Integer businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                cmsActivityServiceImpl.findById(businessId));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:activity:list')")
    @CyOpeLogAnno(title = "system-活动管理-查询活动管理", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "查询活动集合", notes = "查询活动集合")
    @GetMapping(value = "/queryCmsActivity")
    public CyResult querySysContentNewsInformations(CmsActivity cmsActivity) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                cmsActivityServiceImpl.findAll(cmsActivity));
    }

//    @PreAuthorize("@cyPerm.hasPerm('cms:activity:pageSearch')")
    @CyOpeLogAnno(title = "system-活动管理-查询活动", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "分页查询活动集合", notes = "分页查询活动集合")
    @GetMapping(value = "/queryCmsActivityByPagination")
    public CyGridModel listByPagination(CmsActivity cmsActivity) {
        cmsActivityServiceImpl.findAllByPagination(getPaginationUtility(), cmsActivity);
        return getGridModelResponse();
    }

    //修改状态
    @PreAuthorize("@cyPerm.hasPerm('cms:activity:modificationsStatus')")
    @CyOpeLogAnno(title = "system-活动管理管理-修改活动管理状态", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value = "修改活动状态", notes = "修改活动状态")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @PostMapping("/updateStatus/{businessId:\\w+}")
    public CyResult updateStatus(CmsActivity cmsActivity) {
        CyPersistModel data = cmsActivityServiceImpl.updateStatus(cmsActivity);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                cmsActivity);
    }
    @PreAuthorize("@cyPerm.hasPerm('cms:activity:derive')")
    @CyOpeLogAnno(title = "system-活动管理管理-查询活动管理", businessType = CyLogTypeEnum.EXPORT)
    @ApiOperation(value = "导出活动信息", notes = "导出活动信息")
    @GetMapping(value = "/export")
    public void outSysContentNewsInformation(HttpServletResponse response, CmsActivity cmsActivity, @PathVariable @RequestParam(defaultValue = "0") String excelId) {
        String excelName = "";
        switch (excelId) {
            case "0":
                excelName = "活动信息.xls";
                break;
            case "1":
                excelName = "活动信息.xlsx";
                break;
            case "2":
                excelName = "活动信息.csv";
                break;
        }
        List<CmsActivity> cmsActivityList = cmsActivityServiceImpl.export(cmsActivity);
        CyEpExcelUtil.exportExcel(cmsActivityList, "活动信息", "活动信息", CmsActivity.class, excelName, response);
    }
}
